
export function moduleResolverByPaths(root, paths, extensions) {
    const plugin = require("babel-plugin-module-resolver");
    const matchers = createMatchers(paths);
    return [plugin, {
            root,
            extensions,
            resolvePath(specifier, importer, options) {
                let path;
                for (let i = 0; !path && i < matchers.length; i++)
                    path = tryMatcher(matchers[i], plugin.resolvePath, specifier, importer, options);
                return path || plugin.resolvePath(specifier, importer, options);
            },
        }];
}

function tryMatcher(matcher, resolver, specifier, importer, options) {
    let path;
    const [regex, substitutions] = matcher;
    const [, value] = regex.exec(specifier) || [];
    if (value)
        for (let i = 0; !path && i < substitutions.length; i++) {
            specifier = substitutions[i].replace("*", value);
            path = resolver(specifier, importer, options);
        }
    return path;
}

function createMatchers(paths) {
    const matchers = [];
    for (const key of Object.keys(paths)) {
        const pattern = key.replace("*", "(.+)");
        const regex = new RegExp(pattern);
        const substitutions = paths[key].map(toSubstitution);
        matchers.push([regex, substitutions]);
    }
    return matchers;
}
function toSubstitution(value) {
    if (value.startsWith("."))
        value = value.slice(1);
    if (value.startsWith("/"))
        value = value.slice(1);
    return value;
}
//# sourceMappingURL=module-resolver.js.map
